==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowCustomFormFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowCustomForm}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowCustomFormFieldAttributes extends AbstractBeanAttributesDefinition{

    /** formName (Database column: FORM_NAME) */
    static public AttributeDefinition formName =
        new AttributeDefinition("formName")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("FORM_NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** stageId (Database column: STAGE_ID) */
    static public AttributeDefinition stageId =
        new AttributeDefinition("stageId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("STAGE_ID")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** workflow (Database column: WORKFLOW_ID) */
    static public AttributeDefinition workflow =
        new AttributeDefinition("workflow")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("WORKFLOW_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(formName.getName(),formName);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(stageId.getName(),stageId);
        map.put(workflow.getName(),workflow);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/WorkflowCustomFormFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link WorkflowCustomForm}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class WorkflowCustomFormFieldAttributes extends AbstractBeanAttributesDefinition{

    /** formName (Database column: FORM_NAME) */
    static public AttributeDefinition formName =
        new AttributeDefinition("formName")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("FORM_NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** stageId (Database column: STAGE_ID) */
    static public AttributeDefinition stageId =
        new AttributeDefinition("stageId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("STAGE_ID")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** workflow (Database column: WORKFLOW_ID) */
    static public AttributeDefinition workflow =
        new AttributeDefinition("workflow")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("WORKFLOW_CUSTOM_FORM")
                .setDatabaseId("WORKFLOW_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.Workflow.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return "name";
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(formName.getName(),formName);
        map.put(id.getName(),id);
        map.put(name.getName(),name);
        map.put(stageId.getName(),stageId);
        map.put(workflow.getName(),workflow);

        return map;
    }
}
